@@ -30,7 +30,7 @@ use File::Spec;
 sub dl_load_flags { 0x01 } # global option
 
 BEGIN {
-  $VERSION = '1.00';
+  $VERSION = '1.01';
   bootstrap Net::WDNS $VERSION;
 }
 
@@ -186,12 +186,29 @@ my %Const;
   WDNS_TYPE_DHCID
   WDNS_TYPE_NSEC3
   WDNS_TYPE_NSEC3PARAM
+  WDNS_TYPE_TLSA
+
   WDNS_TYPE_HIP
   WDNS_TYPE_NINFO
   WDNS_TYPE_RKEY
   WDNS_TYPE_TALINK
   WDNS_TYPE_CDS
+  WDNS_TYPE_CDNSKEY
+  WDNS_TYPE_OPENPGPKEY
+  WDNS_TYPE_CSYNC
+
   WDNS_TYPE_SPF
+  WDNS_TYPE_UINFO
+  WDNS_TYPE_UID
+  WDNS_TYPE_GID
+  WDNS_TYPE_UNSPEC
+  WDNS_TYPE_NID
+  WDNS_TYPE_L32
+  WDNS_TYPE_L64
+  WDNS_TYPE_LP
+  WDNS_TYPE_EUI48
+  WDNS_TYPE_EUI64
+
   WDNS_TYPE_TKEY
   WDNS_TYPE_TSIG
   WDNS_TYPE_IXFR
@@ -203,6 +220,8 @@ my %Const;
   WDNS_TYPE_CAA
   WDNS_TYPE_TA
   WDNS_TYPE_DLV
+
+
 ));
 
 ###
